<?php

defined('ABSPATH') or exit;

/**
 * Montonio Gateway Admin settings
 */
class Montonio_Financing_Settings extends WC_Payment_Gateway
{
    /**
     * Default currency
     */
    const DEFAULT_CURRENCY = 'EUR';

    /**
     * Default language
     */
    const DEFAULT_LANG = 'en';

    /**
     * @var integer
     */
    protected $publicKey;

    /**
     * @var string
     */
    protected $currency;

    /**
     * @var string
     */
    protected $lang;

    /**
     * @var array
     */
    protected $formFields;

    /**
     * @var array
     */
    protected $mainFormFields;

    /**
     * @var array
     */
    protected $calculatorFormFields;



    /**
     * @return self
     */
    static public function create()
    {
        return new self();
    }

    /**
     * Montonio_Financing_Settings constructor.
     */
    public function __construct()
    {
        $this->currency   = $this::DEFAULT_CURRENCY;
        $this->lang       = $this::DEFAULT_LANG;
        $this->mainFormFields = array(
            'enabled' => array(
                'title'       => __('Enable Montonio', 'montonio-for-woocommerce'),
                'label'       => __('Enable Montonio payment', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'description' => '',
                'default'     => 'no'
            ),
            'sandbox' => array(
                'title'       => __('Sandbox', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'label'       => __('Enable Sandbox mode', 'montonio-for-woocommerce'),
                'default'     => 'yes',
                'description' => __('Enable this to accept payments through Montonio Sandbox API', 'montonio-for-woocommerce'),
            ),
            'publicKey' => array(
                'title'       => __('Access Key', 'montonio-for-woocommerce'),
                'type'        => 'text',
            ),
            'secretKey' => array(
                'title'       => __('Secret Key', 'montonio-for-woocommerce'),
                'type'        => 'password',
                'description' => __('Montonio Public and Secret keys can be obtained from <a target="_blank" href="https://partner.montonio.com">Montonio Partner System</a><br>and Sandbox mode keys from <a target="_blank" href="https://sandbox-partner.montonio.com">Montonio SANDBOX Partner System</a>.', 'montonio-for-woocommerce'),
            ),
            'montonioFinancingOrderPrefix' => array(
                'title'       => __('Order Prefix', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'description' => __('<strong>[MULTISTORE]</strong><br />If you are using Montonio in multiple shops with only one pair of API keys, <br />set the Order Prefix here to distinguish between orders in the Montonio Partner System', 'montonio-for-woocommerce'),
            ),
            'titlev2' => array(
                'title'       => __('Title', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'description' => __(
                    'Payment method title that the customer will see on your website.',
                    'montonio-for-woocommerce'
                ),
                'default'     => __('Compare financing offers', 'montonio-for-woocommerce')
            ),
            'descriptionv2' => array(
                'title'       => __('Description', 'montonio-for-woocommerce'),
                'type'        => 'textarea',
                'css'               => 'width: 400px;',
                'description' => __(
                    'This controls the description which the user sees during checkout.',
                    'montonio-for-woocommerce'
                ),
                'default'     => __('Select the financing offer you like best! With one application you receive multiple financing offers.', 'montonio-for-woocommerce')
            ),
            'minOrderTotal' => array(
                 'title'       => __('Min order total', 'montonio-for-woocommerce'),
                 'type'        => 'text',
                 'default'     => 60,
                 'description' => __(
                     'Minimum order total to show Montonio Financing in checkout. Recommended minimum amount is 60€.',
                     'montonio-for-woocommerce'
                 )
             ),
            // 'maxOrderTotal' => array(
            //     'title'       => __('Max order total (€)', 'montonio-for-woocommerce'),
            //     'description' => __('The price threshold between which Montonio is available as a payment option.<br />The loan calculator also takes this into account', 'montonio-for-woocommerce'),
            //     'type'        => 'text',
            //     'default'     => 10000
            // ),
        );

        // Loan Calculator Widget Settings
        $this->calculatorFormFields = array(
            'calcEnabled' => array(
                'title'       => __('Enable Loan Calculator', 'montonio-for-woocommerce'),
                'label'       => __('Show Montonio Loan Calculator at hooks and shortcodes.', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'description' => '',
                'default'     => 'no'
            ),
            'calcHooks' => array(
                'title'       => __('Hooks', 'montonio-for-woocommerce'),
                'type'        => 'textarea',
                'css'         => 'width: 400px;',
                'description' => __(
                    'This controls where to show loan calculator. These here are the hooks after which the plugin will render the loan calculator.<br /> Please separate the hooks with a comma (my_hook_1, my_hook_2).<br /> For hook reference, see <a href="https://docs.woocommerce.com/wc-apidocs/hook-docs.html" target="_blank"> the official Woocommerce Docs</a>.',
                    'montonio-for-woocommerce'
                ),
                'default'     => 'woocommerce_before_add_to_cart_button'
            ),
            'calcLogoURL' => array(
                'title'       => __('Logo URL', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'default'     => '',
            ),
            'calcInfoPageURL' => array(
                'title'       => __('Info page URL', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'default'     => ''
            ),
            'calcDefaultProductPrice' => array(
                'title'       => __('Default Product Price (€)', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'default'     => 399.99
            ),
            'calcShowModal' => array(
                'title'       => __('Show popup Modal', 'montonio-for-woocommerce'),
                'label'       => __('Show info popup modal "How to apply for financing?"', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'description' => '',
                'default'     => 'yes'
            ),
            'calcCSS' => array(
                'title'       => __('Custom CSS', 'montonio-for-woocommerce'),
                'type'        => 'textarea',
                'css'         => 'width: 400px; min-height: 250px',
                'description' => __(
                    'Here you can inject custom CSS to the loan calculator',
                    'montonio-for-woocommerce'
                ),
                'default'     => ''
            ),
            'calcShortcodeExample' => array(
                'title'       => __('Shortcode', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'custom_attributes' => array(
                    'readonly' => 'readonly'
                ),
                'default'     => '[montonio_calculator]',
                'description' => __(
                    'Use this shortcode to show the loan calculator at a page.<br /> If no attributes are set, the shortcode will render the widget with set options like on product pages.' . $this->_getShortcodeAttributesTable(),
                    'montonio-for-woocommerce'
                ),
            ),
            'calcLoadScriptMode' => array(
                'title'       => __('Load Script mode', 'montonio-for-woocommerce'),
                'type'        => 'select',
                'class'          => 'wc-enhanced-select',
                'default'     => 'Default',
                'description'       => __('Load Script with some other strategy than enqueue\'ing the Default WordPress way. Use this ONLY if your widget isn\'t rendering.', 'montonio-for-woocommerce'),
                'options'     => array('Default', 'Echo <script>'),
            ),
        );

        $this->formFields = array_merge(
            $this->mainFormFields,
            $this->calculatorFormFields
        );
    }

    /**
     * @param object $tabs
     * @param boolean [Optional] $print
     *
     * @return boolean|string
     */
    public function buildAdminFormHtml($tabs, $print = true)
    {
        $htmlData = $this->generateFormFields($tabs);

        // enqueue admin script 
        wp_enqueue_script(
            'montonio-checkout-order-pay',
            WC_MONTONIO_PLUGIN_URL . '/financing/assets/js/montonio-admin-settings.js'
        );

        $html  = '<div class="plugin_config">';
        $html .= '<h2>' . $htmlData['links'] . '</h2>';
        $html .= '<div style="clear:both;"><hr /></div>';
        $html .= $htmlData['tabs'];
        $html .= '</div>';

        if ($print) {
            print_r($html);
            return $print;
        } else {
            return $html;
        }
    }

    /**
     * @return array
     */
    public function generateNewSettings()
    {
        return [
            'statuses'  => $this->getStatusList()
        ];
    }

    /**
     * @return array
     */
    protected function getStatusList()
    {
        $wcStatus = array_keys(wc_get_order_statuses());
        $orderStatus = array();
        foreach ($wcStatus as $key => $value) {
            $orderStatus[$wcStatus[$key]] = wc_get_order_status_name($wcStatus[$key]);
        }

        return $orderStatus;
    }

    /**
     * @param object $tabs
     *
     * @return array
     */
    protected function generateFormFields($tabs)
    {
        $tabsLink = '';
        $tabsContent = '';
        foreach ($tabs as $key => $value) {
            $tabsLink .= '<a href="javascript:void(0)"';
            $tabsLink .= ' id="tab' . $key . '" class="nav-tab"';
            $tabsLink .= ' data-cont="content' . $key . '">';
            $tabsLink .=  $value['name'] . '</a>';

            $tabsContent .= '<div id="content' . $key . '" class="tabContent">';
            $tabsContent .= '<table class="form-table">' . $value['slice'] . '</table>';
            $tabsContent .= '</div>';
        }

        return [
            'links' => $tabsLink,
            'tabs'  => $tabsContent
        ];
    }

    /**
     * @return integer
     */
    public function getPublicKey()
    {
        return $this->publicKey;
    }

    /**
     * @param integer $publicKey
     *
     * @return self
     */
    public function setPublicKey($publicKey)
    {
        $this->publicKey = $publicKey;
        return $this;
    }

    /**
     * @return string
     */
    public function getCurrency()
    {
        return $this->currency;
    }

    /**
     * @param string $currency
     *
     * @return self
     */
    public function setCurrency($currency)
    {
        $this->currency = $currency;
        return $this;
    }

    /**
     * @return string
     */
    public function getLang()
    {
        return $this->lang;
    }

    /**
     * @param string $lang
     *
     * @return self
     */
    public function setLang($lang)
    {
        $this->lang = $lang;

        return $this;
    }

    /**
     * @return array
     */
    public function getFormFields()
    {
        return $this->formFields;
    }

    /**
     * @param array $formFields
     *
     * @return self
     */
    public function setFormFields($formFields)
    {
        $this->formFields = $formFields;

        return $this;
    }

    /**
     * @return array
     */
    public function getCalculatorFormFields()
    {
        return $this->calculatorFormFields;
    }

    /**
     * @param array $formFields
     *
     * @return self
     */
    public function setCalculatorFormFields($calculatorFormFields)
    {
        $this->calculatorFormFields = $calculatorFormFields;

        return $this;
    }

    /**
     * Get the attributes info table for calculator shortcode
     * 
     * @return string
     */
    private function _getShortcodeAttributesTable() {
        return '<table class="wp-list-table striped">
        <thead>
            <tr>
                <th>Attribute</th>
                <th>Description</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>target-id</td>
                <td>The element ID to bind to (also creates the element)</td>
            </tr>
            <tr>
                <td>class</td>
                <td>The CSS class to add to the calculator.</td>
            </tr>
            <tr>
                <td>css</td>
                <td>The CSS string for custom CSS.</td>
            </tr>
            <tr>
                <td>name</td>
                <td>The name to display in the calculator.</td>
            </tr>
            <tr>
                <td>locale</td>
                <td>The language to use in the calculator (supported: <strong>et, lt, en, ru</strong>). By default, the calculator resolves locale itself.</td>
            </tr>
            <tr>
                <td>logo-url</td>
                <td>The logo URL</td>
            </tr>
            <tr>
                <td>show-modal</td>
                <td><strong>[true/false]</strong> Show popup modal?</td>
            </tr>
            <tr>
                <td>info-page-url</td>
                <td>The info page URL</td>
            </tr>
            <tr>
                <td>product-price</td>
                <td>The price to use in the calculator.</td>
            </tr>
        </tbody>
        </table>
        <br>
        Example: [montonio_calculator class="my-class" locale="lt" product-price="405.85"]';
    }
}
