<?php

defined('ABSPATH') or exit;

class Wc_Montonio_Widget_Calculator extends WC_Settings_API
{
    const CALC_LOAD_SCRIPT_MODE_DEFAULT = 0;
    const CALC_LOAD_SCRIPT_MODE_ECHO = 1;
    protected $loadSciptMode;

    protected $hooks;
    protected $enabled;
    protected $montonioEnabled;

    protected $css;
    protected $name;
    protected $class;
    protected $locale;
    protected $logoURL;
    protected $showModal;
    protected $infoPageURL;
    protected $productPrice;
    protected $fixedPrice;

    protected $targetId;
    protected $environment;

    protected $publicKey;
    

    // Todo: Configurable fields
    const MIN_ORDER_TOTAL = 60;
    const MAX_ORDER_TOTAL = 10000;

    /**
     * Shortcode identifier
     */
    protected $scriptHandle;

    /**
     * Return new instance of Wc_Montonio_Widget_Calculator
     * @param array $options: Configuration from shortcode 
     * 
     * @return object 
     */
    public static function create($instanceId = null, $options = null)
    {
        return new self($instanceId, $options);
    }

    /**
     * Constructor for Wc_Montonio_Widget_Calculator
     * @param array $options: Configuration from shortcode 
     * 
     * @return void 
     */
    public function __construct($id, $o)
    {
        $this->scriptHandle = 'montonio-ui-calculator' . ($id ? '-' . $id : '');

        // intercept loading loan calculator script to pass data-attributes
        add_filter('script_loader_tag', array($this, 'setup_montonio_calculator'), 10, 2);

        // setup
        $this->id              = 'montonio';
        $this->enabled         = $this->get_option('calcEnabled');
        $this->hooks           = $this->get_option('calcHooks');
        $this->publicKey       = $this->get_option('publicKey');
        $this->montonioEnabled = $this->get_option('enabled');
        $this->environment     = ($this->get_option('sandbox') === 'yes' ? 'sandbox' : 'production');
        $this->targetId =     isset($o['target-id'])     ? $o['target-id']     : 'montonioLCTarget'; // default target div id
        $this->class =        isset($o['class'])         ? $o['class']         : '';
        $this->css =          isset($o['css'])           ? $o['css']           : $this->get_option('calcCSS');
        $this->name =         isset($o['name'])          ? $o['name']          : $this->get_option('title');
        $this->locale =       isset($o['locale'])        ? $o['locale']        : $this->_resolveLocale();
        $this->logoURL =      isset($o['logo-url'])      ? $o['logo-url']      : $this->get_option('calcLogoURL');
        $this->showModal =    isset($o['show-modal'])    ? $o['show-modal']    : $this->get_option('calcShowModal') === 'yes';
        $this->infoPageURL =  isset($o['info-page-url']) ? $o['info-page-url'] : $this->get_option('calcInfoPageURL');

        $this->loadSciptMode = $this->get_option('calcLoadScriptMode') || 0;

        // if price is provided (in shortcode atts), use this for calculations instead
        if (isset($o['product-price'])) {
            $this->fixedPrice = $o['product-price'];
            $this->productPrice = $this->fixedPrice;
        } else {
            $this->productPrice = $this->get_option('calcDefaultProductPrice');
        }

        if ($this->enabled === 'yes' && $this->montonioEnabled === 'yes') {
            if ($id) {
                $this->renderWidget();
            } else {
                $this->register();
                add_shortcode('montonio_calculator', array($this, 'renderWidgetWithShortcode'));
            }
        }
    }

    /**
     * Register 'renderWidget' action for configured hooks
     * 
     * @return void
     */
    public function register()
    {
        $hookString = str_replace(' ', '', $this->hooks);
        $hooks = explode(",", $hookString);
        foreach ($hooks as $hook) {
            add_action($hook, array($this, 'renderWidget'));
        }
    }

    /**
     * Pass data attributes to loan calculator script 
     * 
     * @return string
     */
    public function setup_montonio_calculator($tag, $handle)
    {
        if ($handle !== $this->scriptHandle) return $tag;

        // get widget options from configuration
        $attr = 'data-product-price="' . $this->getInjectableProductPrice() . '"' .
            'data-access-key="' . $this->publicKey . '" ' .
            'data-environment="' . $this->environment . '" ' .
            'data-name="' . $this->name . '" ' .
            'data-css="' . $this->css . '" ' .
            'data-class="' . $this->class . '" ' .
            'data-locale="' . $this->locale . '" ' .
            'data-logo-url="' . $this->logoURL . '" ' .
            'data-show-modal="' . ($this->showModal ? "true" : "false") . '" ' .
            'data-info-page-url="' . $this->infoPageURL . '" ' .
            'data-target-id="' . $this->targetId . '" ';

        // add data attributes
        return str_replace(' src', $attr . 'src', $tag);
    }

    /**
     * Get the price to use in the calculator
     * 
     * @return float/string
     */
    protected function getInjectableProductPrice()
    {
        if ($this->fixedPrice) return $this->fixedPrice;

        $priceToUse = $this->productPrice;

        if (is_product()) {
            $product = wc_get_product( get_the_ID() );
            $price = $product->get_price();
            if ($price && floatval($price) > 0) {
                $priceToUse = $price;
            }
        } else if (is_cart() || is_checkout()) {
            if (WC()->cart && WC()->cart->get_total('raw')) {
                $priceToUse = (float) ( WC()->cart->get_total('raw') );
            }
        }
        return $priceToUse;
        // check price threshold
        if (
            // TODO:
            // floatval($priceToUse) > (float) $this->get_option('minOrderTotal') &&
            // floatval($priceToUse) < (float) $this->get_option('maxOrderTotal')
            floatval($priceToUse) > self::MIN_ORDER_TOTAL &&
            floatval($priceToUse) < self::MAX_ORDER_TOTAL
        ) {
            return $priceToUse;
        } else return 'INVALID_PRICE';
    }

    /**
     * Create the target div to anchor the loan calculator to
     * 
     * @return void
     */
    public function renderWidget()
    {
        // set the target after which the Loan Calculator is rendered.
        echo '<div id="' . $this->targetId . '"></div>';
        $this->loadCalculatorScript();
    }

    private function loadCalculatorScript() {
        switch ($this->loadSciptMode) {
            case self::CALC_LOAD_SCRIPT_MODE_ECHO:
                $tmp = '
                <script data-product-price="' . $this->getInjectableProductPrice() . '"' .
                'data-access-key="' . $this->publicKey . '" ' .
                'data-environment="' . $this->environment . '" ' .
                'data-name="' . $this->name . '" ' .
                'data-css="' . $this->css . '" ' .
                'data-class="' . $this->class . '" ' .
                'data-locale="' . $this->locale . '" ' .
                'data-logo-url="' . $this->logoURL . '" ' .
                'data-show-modal="' . ($this->showModal ? "true" : "false") . '" ' .
                'data-info-page-url="' . $this->infoPageURL . '" ' .
                'data-target-id="' . $this->targetId . '" 
                type="text/javascript" 
                src="https://public.montonio.com/assets/UI/calculator/index.js">
                </script>';
                echo $tmp;
            break;
            
            default:
                wp_enqueue_script(
                    $this->scriptHandle,
                    'https://public.montonio.com/assets/UI/calculator/index.js'
                );
            break;
        }
    }

    /**
     * Create new instance of Wc_Montonio_Widget_Calculator
     * from shortcode 
     *
     * @return void 
     */
    public function renderWidgetWithShortcode($atts)
    {
        self::create(wp_generate_uuid4(), $atts);
    }

    /**
     * Figure out which language to use for the widget
     * 
     * @return string
     */
    private function _resolveLocale()
    {
        $currentLocale = get_locale();
        switch ($currentLocale) {
            case 'et':
                return 'et';
            case 'ru_RU':
                return 'ru';
            case 'lt_LT':
                return 'lt';
            default:
                return 'en';
        }
    }
}
