<?php
defined('ABSPATH') or exit;

abstract class Montonio_Shipping_Method_Settings
{
    /**
     * @var array
     */
    protected $settings;

    /**
     * @var array
     */
    protected $formFields;

    /**
     * @var array
     */
    protected $instanceFormFields;

    /**
     * @var string
     */
    protected $defaultTitle;

    /**
     * @var float
     */
    protected $maximumWeight;

    /**
     * @return void
     */
    public function __construct()
    {
        $this->initConfigurationFields();
    }

    /**
     * @return void
     */
    protected function initConfigurationFields()
    {
        $this->initBasicFormFields();
        $this->initInstanceFormFields();
    }

    protected function getCommonBasicFormFields()
    {
        return array();
    }

    protected function getCommonInstanceFormFields()
    {
        return array(
            'title' => array(
                'title'       => __('Title', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'description' => __(
                    'Shipping method title that the customer will see at checkout',
                    'montonio-for-woocommerce'
                ),
                'default'     => $this->defaultTitle
            ),
            'price' => array(
                'title'       => __('Shipping option price', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'description' => __(
                    'Price for customer when choosing this as shipping method',
                    'montonio-for-woocommerce'
                ),
                'default'     => 0
            ),
            'enableFreeShippingThreshold' => array(
                'title'       => __('Enable free shipping threshold', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'description' => __('Allow free shipping if cart total exceeds set sum', 'montonio-for-woocommerce'),
                'default'     => 'no'
            ),
            'freeShippingThreshold' => array(
                'title'       => __('Free shipping threshold', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'description' => __('Minimum cart total for free shipping', 'montonio-for-woocommerce'),
                'default'     => 50
            ),
            'enablePackageMeasurementsCheck' => array(
                'title'       => __('Enable package measurements check', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'description' => __(
                    'Hide this option if package\'s weight or dimensions exceed limits',
                    'montonio-for-woocommerce'
                ),
                'default'     => 'yes'
            ),
            'maximumWeight' => array(
                'title' => __('Maximum weight (kg)', 'montonio-for-woocommerce'),
                'type' => 'number',
                'description' => __(
                    'The total weight of items in the cart that is allowed for this option to be displayed',
                    'montonio-for-woocommerce'
                ),
                'default' => $this->maximumWeight
            ),
            'hideWhenNoMeasurements' => array(
                'title'       => __('Hide when no measurements', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'description' => __(
                    'Hide this option when an item in cart has no set weight or dimensions',
                    'montonio-for-woocommerce'
                ),
                'default'     => 'no'
            )
        );
    }

    /**
     * @return void
     */
    public function montonio_sync_pickup_points()
    {
        do_action('montonio_shipping_sync_pickup_points');
    }

    // =========================================================================
    // Getters and Setters
    // =========================================================================

    /**
     * @return array
     */
    public function getSettings()
    {
        return $this->settings;
    }

    /**
     * @param array $settings
     * @return void
     */
    public function setSettings($settings)
    {
        $this->settings = $settings;
    }

    /**
     * @return array
     */
    public function getFormFields()
    {
        return $this->formFields;
    }

    /**
     * @param array $formFields
     * @return void
     */
    public function setFormFields($formFields)
    {
        $this->formFields = $formFields;
    }

    /**
     * @return array
     */
    public function getInstanceFormFields()
    {
        return $this->instanceFormFields;
    }

    /**
     * @param array $instanceFormFields
     * @return void
     */
    public function setInstanceFormFields($instanceFormFields)
    {
        $this->instanceFormFields = $instanceFormFields;
    }
}