<?php
defined('ABSPATH') or exit;

if (!class_exists('MontonioHelper')) {
    require_once dirname(dirname(__FILE__)) . '/libraries/MontonioHelper.php';
}

class Montonio_Shipping_Settings extends WC_Settings_Page
{
    /**
     * @return void
     */
    public function __construct()
    {
        $this->id    = 'montonio_shipping';
        $this->label = __('Montonio Shipping', 'montonio-for-woocommerce');

        parent::__construct();
    }

    /**
     * @return self
     */
    public static function create()
    {
        return new self();
    }

    /**
     * Legacy support for Woocommerce 5.4 and earlier
     * @return array
     */
    public function get_settings()
    {
        return $this->get_settings_for_default_section();
    }

    /**
     * Used when creating Montonio shipping settings tab
     * @return array
     */
    public function get_sections()
    {
        return array(
            '' => __('Montonio API access', 'montonio-for-woocommerce')
        );
    }

    /**
     * Used when creating Montonio shipping settings tab
     * @return array
     */
    public function get_settings_for_default_section()
    {
        $countries     = array('' => '-- Choose country --');
        $countries     = array_merge($countries, (new WC_Countries())->get_countries());
        $orderStatuses = wc_get_order_statuses();

        return array(
            array(
                'title' => __('General', 'montonio-for-woocommerce'),
                'type'  => 'title',
                'id'    => 'montonio_shipping_general'
            ),
            array(
                'title'       => __('Enable Montonio shipping', 'montonio-for-woocommerce'),
                'label'       => __('Enabled', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'default'     => 'no',
                'id'          => 'montonio_shipping_enabled'
            ),
            array(
                'title'   => __('Access Key', 'montonio-for-woocommerce'),
                'type'    => 'text',
                'default' => '',
                'id'      => 'montonio_shipping_accessKey'
            ),
            array(
                'title'   => __('Secret Key', 'montonio-for-woocommerce'),
                'type'    => 'password',
                'desc'    => __('Montonio Access and Secret keys can be obtained from <a target="_blank" href="https://partner.montonio.com">Montonio Partner System</a>.', 'montonio-for-woocommerce'),
                'default' => '',
                'id'      => 'montonio_shipping_secretKey'
            ),
//            array(
//                'type'    => 'select',
//                'title'   => __('Environment', 'montonio-for-woocommerce'),
//                'class'   => 'wc-enhanced-select',
//                'default' => 'production',
//                'desc'    => __('Use the Sandbox environment for testing only', 'montonio-for-woocommerce'),
//                'options' => array(
//                    'production' => __('Production', 'montonio-for-woocommerce'),
//                    'sandbox'    => __('Sandbox', 'montonio-for-woocommerce'),
//                ),
//                'id'      => 'montonio_shipping_environment'
//            ),
            array(
                'type'    => 'select',
                'title'   => __('Order status when label printed', 'montonio-for-woocommerce'),
                'class'   => 'wc-enhanced-select',
                'default' => isset($orderStatuses['wc-mon-label-printed']) ? 'wc-mon-label-printed' : 'no-change',
                'desc'    => __(
                    'What status should order be changed to in Woocommerce when label is printed in Montonio?<br>
                    Status will only be changed when order\'s current status is "Processing".',
                    'montonio-for-woocommerce'
                ),
                'options' => array_merge(
                    array(
                        'no-change' => __('-- Do not change status --', 'montonio-for-woocommerce')
                    ),
                    $orderStatuses
                ),
                'id'      => 'montonio_shipping_orderStatusWhenLabelPrinted'
            ),
            array(
                'id'      => 'montonio_email_tracking_code_text',
                'title'   => __('Tracking code text for e-mail', 'montonio-for-woocommerce'),
                'type'    => 'text',
                'desc'    => __(
                    'Text used before tracking codes in e-mail placeholder {montonio_tracking_info}.<br>
                     Appears only if order has Montonio shipping and existing tracking code(s).',
                    'montonio-for-woocommerce'
                ),
                'default' => 'Track your shipment:'
            ),
            array(
                'id'      => 'montonio_shipping_order_prefix',
                'title'   => __('Order Prefix', 'montonio-for-woocommerce'),
                'type'    => 'text',
                'desc'    => __(
                    '<strong>[MULTISTORE]</strong><br />
                     If you are using Montonio in multiple shops with only one pair of API keys, <br />
                     set the Order Prefix here to distinguish between orders in the Montonio Partner System',
                    'montonio-for-woocommerce'
                ),
                'default' => '', // maybe translatable?
            ),
            array(
                'title'       => __('Show shipping provider logos at checkout', 'montonio-for-woocommerce'),
                'label'       => __('Enabled', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'default'     => 'no',
                'id'          => 'montonio_shipping_show_provider_logos'
            ),
            array(
                'type' => 'sectionend',
                'id'   => 'montonio_shipping_general'
            ),
            array(
                'title' => __("Sender's information", 'montonio-for-woocommerce'),
                'type'  => 'title',
                'id'    => 'montonio_shipping_sender_info'
            ),
            array(
                'title'   => __("Sender's name", 'montonio-for-woocommerce'),
                'type'    => 'text',
                'default' => '',
                'custom_attributes' => array( 'required' => 'required' ),
                'id'      => 'montonio_shipping_senderName'
            ),
            array(
                'title'   => __("Sender's phone", 'montonio-for-woocommerce'),
                'type'    => 'text',
                'default' => '',
                'custom_attributes' => array( 'required' => 'required' ),
                'id'      => 'montonio_shipping_senderPhone'
            ),
            array(
                'title'   => __("Sender's street address", 'montonio-for-woocommerce'),
                'type'    => 'text',
                'default' => '',
                'custom_attributes' => array( 'required' => 'required' ),
                'id'      => 'montonio_shipping_senderStreetAddress'
            ),
            array(
                'title'   => __("Sender's city", 'montonio-for-woocommerce'),
                'type'    => 'text',
                'default' => '',
                'custom_attributes' => array( 'required' => 'required' ),
                'id'      => 'montonio_shipping_senderLocality'
            ),
            array(
                'title'   => __("Sender's county", 'montonio-for-woocommerce'),
                'type'    => 'text',
                'default' => '',
                'custom_attributes' => array( 'required' => 'required' ),
                'id'      => 'montonio_shipping_senderRegion'
            ),
            array(
                'title'   => __("Sender's postal code", 'montonio-for-woocommerce'),
                'type'    => 'text',
                'default' => '',
                'custom_attributes' => array( 'required' => 'required' ),
                'id'      => 'montonio_shipping_senderPostalCode'
            ),
            array(
                'title'   => __("Sender's country", 'montonio-for-woocommerce'),
                'type'    => 'select',
                'options' => $countries,
                'default' => '',
                'custom_attributes' => array( 'required' => 'required' ),
                'id'      => 'montonio_shipping_senderCountry'
            ),
            array(
                'type' => 'sectionend',
                'id'   => 'montonio_shipping_sender_info'
            ),
            array(
                'title' => __("Advanced", 'montonio-for-woocommerce'),
                'type'  => 'title',
                'id'    => 'montonio_shipping_advanced'
            ),
            array(
                'id' => 'montonio_shipping_css',
                'title' => __('CSS for checkout', 'montonio-for-woocommerce'),
                'type' => 'textarea',
                'desc' => __(
                    'Here you can insert additional CSS rules for checkout.',
                    'montonio-for-woocommerce'
                ),
            ),
            array(
                'title' => __('Enqueue Mode', 'montonio-for-woocommerce'),
                'type' => 'select',
                'class' => 'wc-enhanced-select',
                'default' => 'enqueue',
                'desc' => __(
                    'Select how to enqueue CSS and JavaScript files to your store',
                    'montonio-for-woocommerce'
                ),
                'options'     => array(
                    'enqueue' => 'Enqueue (recommended)',
                    'echo' => 'Echo',
                ),
                'id' => 'montonio_shipping_enqueue_mode'
            ),
            array(
                'title'       => __('Re-register selectWoo script', 'montonio-for-woocommerce'),
                'label'       => __('Yes', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'desc' => __(
                    'Some themes may deregister selectWoo (used for advanced dropdown functionality). Use this if the pickup points selection is not searchable.',
                    'montonio-for-woocommerce'
                ),
                'default'     => 'no',
                'id'          => 'montonio_shipping_register_selectWoo'
            ),
            array(
                'type' => 'sectionend',
                'id'   => 'montonio_shipping_advanced'
            )
        );
    }

}
