<?php
defined('ABSPATH') or exit;

require_once dirname(dirname(__FILE__)) . '/class-montonio-shipping-method.php';

class Montonio_DPD_Courier extends Montonio_Shipping_Method
{
    const MAXIMUM_LONGEST_SIDE = 175; // cm
    const MAXIMUM_SUM_OF_LONGEST_SIDE_AND_BOTTOM_GIRTH = 300; // cm
    const MAXIMUM_WEIGHT = 31.5; // kg

    /**
     * Called from parent's constructor
     * @return void
     */
    protected function init($instanceId = 0)
    {
        $this->id                 = 'montonio_dpd_courier';
        $this->instance_id        = absint($instanceId);
        $this->method_title       = __('Montonio DPD courier', 'montonio-for-woocommerce');
        $this->method_description = __('DPD courier', 'montonio-for-woocommerce');
        $this->supports           = array(
            'shipping-zones',
            'instance-settings',
            'instance-settings-modal',
            // 'settings'
        );

        $this->shippingMethodIdentifier = 'dpd_courier';
        $this->providerName = 'dpd';
        $this->type = 'courier';
        $this->logo = 'https://public.montonio.com/images/shipping_provider_logos/dpd.png';

        // Load the settings API
        $this->init_form_fields();
        $this->init_settings();

        $this->title = __(
            $this->get_option('title', __('DPD courier', 'montonio-for-woocommerce')),
            'montonio-for-woocommerce'
        );
    }

    /**
     * @return void
     */
    public function init_form_fields()
    {
        require_once 'class-montonio-dpd-courier-settings.php';
        $this->setPluginSettings(Montonio_DPD_Courier_Settings::create());
        $this->instance_form_fields = $this->getPluginSettings()->getInstanceFormFields();
        $this->form_fields = $this->getPluginSettings()->getFormFields();
    }

    protected function validatePackageWeight($package)
    {
        $packageWeight = $this->calculatePackageWeight($package);
        return $packageWeight <= $this->get_option('maximumWeight', self::MAXIMUM_WEIGHT);
    }

    protected function validatePackageDimensions($package)
    {
        $packageDimensions = $this->calculatePackageDimensions($package);
        if ($packageDimensions[2] > self::MAXIMUM_LONGEST_SIDE) {
            return false;
        }

        $sumOfLongestSideAndBottomGirth = 2 * ($packageDimensions[0] + $packageDimensions[1]) + $packageDimensions[2];
        if ($sumOfLongestSideAndBottomGirth > self::MAXIMUM_SUM_OF_LONGEST_SIDE_AND_BOTTOM_GIRTH) {
            return false;
        }

        return true;
    }
}
