<?php
defined('ABSPATH') or exit;

require_once dirname(dirname(__FILE__)) . '/class-montonio-shipping-method.php';

class Montonio_Itella_Courier extends Montonio_Shipping_Method
{
    const MAXIMUM_DIMENSIONS = [60, 60, 120]; // lowest to highest (cm)
    const MAXIMUM_WEIGHT     = 35; // kg

    /**
     * Called from parent's constructor
     * @return void
     */
    protected function init($instanceId = 0)
    {
        $this->id                 = 'montonio_itella_courier';
        $this->instance_id        = absint($instanceId);
        $this->method_title       = __('Montonio Itella courier', 'montonio-for-woocommerce');
        $this->method_description = __('Itella courier', 'montonio-for-woocommerce');
        $this->supports           = array(
            'shipping-zones',
            'instance-settings',
            'instance-settings-modal'
        );

        $this->shippingMethodIdentifier = 'itella_courier';
        $this->providerName = 'itella';
        $this->type = 'courier';
        $this->logo = 'https://public.montonio.com/images/shipping_provider_logos/itella.png';

        // Load the settings API
        $this->init_form_fields();
        $this->init_settings();

        $this->title = __(
            $this->get_option('title', __('Itella courier', 'montonio-for-woocommerce')),
            'montonio-for-woocommerce'
        );
    }

    /**
     * @return void
     */
    public function init_form_fields()
    {
        require_once 'class-montonio-itella-courier-settings.php';
        $this->setPluginSettings(Montonio_Itella_Courier_Settings::create());
        $this->instance_form_fields = $this->getPluginSettings()->getInstanceFormFields();
        $this->form_fields = $this->getPluginSettings()->getFormFields();
    }

    protected function validatePackageWeight($package)
    {
        $packageWeight = $this->calculatePackageWeight($package);
        return $packageWeight <= $this->get_option('maximumWeight', self::MAXIMUM_WEIGHT);
    }

    protected function validatePackageDimensions($package)
    {
        $packageDimensions = $this->calculatePackageDimensions($package);

        return ($packageDimensions[0] <= self::MAXIMUM_DIMENSIONS[0]) &&
            ($packageDimensions[1] <= self::MAXIMUM_DIMENSIONS[1]) &&
            ($packageDimensions[2] <= self::MAXIMUM_DIMENSIONS[2]);
    }
}
