<?php
defined('ABSPATH') or exit;

require_once dirname(dirname(__FILE__)) . '/class-montonio-shipping-method.php';

class Montonio_Omniva_Courier extends Montonio_Shipping_Method
{
    const MAXIMUM_LONGEST_SIDE = 150; // cm
    const MAXIMUM_SUM_OF_LONGEST_SIDE_AND_BOTTOM_GIRTH = 300; // cm
    const MAXIMUM_WEIGHT = 30; // kg

    /**
     * Called from parent's constructor
     * @return void
     */
    protected function init($instanceId = 0)
    {
        $this->id                 = 'montonio_omniva_courier';
        $this->instance_id        = absint($instanceId);
        $this->method_title       = __('Montonio Omniva courier', 'montonio-for-woocommerce');
        $this->method_description = __('Omniva courier', 'montonio-for-woocommerce');
        $this->supports           = array(
            'shipping-zones',
            'instance-settings',
            'instance-settings-modal'
        );

        $this->shippingMethodIdentifier = 'omniva_courier';
        $this->providerName = 'omniva';
        $this->type = 'courier';
        $this->logo = 'https://public.montonio.com/images/shipping_provider_logos/omniva.png';

        // Load the settings API
        $this->init_form_fields();
        $this->init_settings();

        $this->title = __(
            $this->get_option('title', __('Omniva courier', 'montonio-for-woocommerce')),
            'montonio-for-woocommerce'
        );
    }

    /**
     * @return void
     */
    public function init_form_fields()
    {
        require_once 'class-montonio-omniva-courier-settings.php';
        $this->setPluginSettings(Montonio_Omniva_Courier_Settings::create());
        $this->instance_form_fields = $this->getPluginSettings()->getInstanceFormFields();
        $this->form_fields = $this->getPluginSettings()->getFormFields();
    }

    protected function validatePackageWeight($package)
    {
        $packageWeight = $this->calculatePackageWeight($package);
        return $packageWeight <= $this->get_option('maximumWeight', self::MAXIMUM_WEIGHT);
    }

    protected function validatePackageDimensions($package)
    {
        $packageDimensions = $this->calculatePackageDimensions($package);
        if ($packageDimensions[2] > self::MAXIMUM_LONGEST_SIDE) {
            return false;
        }

        $sumOfLongestSideAndBottomGirth = 2 * ($packageDimensions[0] + $packageDimensions[1]) + $packageDimensions[2];
        if ($sumOfLongestSideAndBottomGirth > self::MAXIMUM_SUM_OF_LONGEST_SIDE_AND_BOTTOM_GIRTH) {
            return false;
        }

        return true;
    }
}
