<?php
defined('ABSPATH') or exit;

require_once dirname(dirname(__FILE__)) . '/class-montonio-shipping-method.php';

class Montonio_Omniva_Parcel_Machines extends Montonio_Shipping_Method
{
    const MAXIMUM_DIMENSIONS = [38, 39, 64]; // lowest to highest (cm)
    const MAXIMUM_WEIGHT     = 30; // kg

    /**
     * Called from parent's constructor
     * @return void
     */
    protected function init($instanceId = 0)
    {
        $this->id                 = 'montonio_omniva_parcel_machines';
        $this->instance_id        = absint($instanceId);
        $this->method_title       = __('Montonio Omniva parcel machines', 'montonio-for-woocommerce');
        $this->method_description = __('Omniva parcel machines', 'montonio-for-woocommerce');
        $this->supports           = array(
            'shipping-zones',
            'instance-settings',
            'instance-settings-modal',
            // 'settings'
        );

        $this->shippingMethodIdentifier = 'omniva_parcel_machines';
        $this->providerName = 'omniva';
        $this->type = 'parcel_machine';
        $this->logo = 'https://public.montonio.com/images/shipping_provider_logos/omniva.png';

        // Load the settings API
        $this->init_form_fields();
        $this->init_settings();

        $this->title = __(
            $this->get_option('title', __('Omniva parcel machine', 'montonio-for-woocommerce')),
            'montonio-for-woocommerce'
        );
    }

    /**
     * @return void
     */
    public function init_form_fields()
    {
        require_once "class-montonio-omniva-parcel-machines-settings.php";
        $this->setPluginSettings(Montonio_Omniva_Parcel_Machines_Settings::create());
        $this->instance_form_fields = $this->getPluginSettings()->getInstanceFormFields();
        $this->form_fields = $this->getPluginSettings()->getFormFields();
    }

    protected function validatePackageWeight($package)
    {
        $packageWeight = $this->calculatePackageWeight($package);
        return $packageWeight <= $this->get_option('maximumWeight', self::MAXIMUM_WEIGHT);
    }

    protected function validatePackageDimensions($package)
    {
        $packageDimensions = $this->calculatePackageDimensions($package);

        return ($packageDimensions[0] <= self::MAXIMUM_DIMENSIONS[0]) &&
            ($packageDimensions[1] <= self::MAXIMUM_DIMENSIONS[1]) &&
            ($packageDimensions[2] <= self::MAXIMUM_DIMENSIONS[2]);
    }
}
