<?php

defined('ABSPATH') or exit;

require_once 'class-montonio-split.php';

/**
 * This class holds logic for the Settings screen located at
 * Woocommerce -> Payments -> Montonio Payments
 *
 * The class handles building the settings form and input validation.
 */
class Montonio_Split_Settings
{
    const DEFAULT_CURRENCY = 'EUR';
    const DEFAULT_LANG     = 'en';

    protected $splitMethodSettings;

    /**
     * @var integer
     */
    protected $settings;

    /**
     * @var string
     */
    protected $currency;

    /**
     * @var string
     */
    protected $lang;

    /**
     * @var array
     */
    protected $formFields;

    /**
     * @var array
     */
    protected $configurationFormFields;

    /**
     * @var array
     */
    protected $advancedFormFields;

    /**
     * @return self
     */
    static public function create()
    {
        return new self();
    }

    /**
     * Montonio_Financing_Settings constructor.
     */
    public function __construct()
    {
        $this->lang     = $this::DEFAULT_LANG;
        $this->currency = $this::DEFAULT_CURRENCY;
    }

    public function compose()
    {
        $this->formFields = $this->getConfigurationFields();
    }

    // =========================================================================
    // Admin notice messages
    // =========================================================================

    // public function montonio_error_failed_to_sync_banks()
    // {
    //     return $this->montonio_show_notice(
    //         __('Montonio Payments was unable to sync banks in the background.', 'montonio-for-woocommerce'),
    //         'error'
    //     );
    // }

    // public function montonio_error_missing_apikeys()
    // {
    //     return $this->montonio_show_notice(
    //         __('Montonio Payments was disabled due to missing API keys.', 'montonio-for-woocommerce'),
    //         'error'
    //     );
    // }

    // public function montonio_show_notice($message, $severity = 'success')
    // {
    //     if (!$message) {
    //         return;
    //     }

    //     echo '<div class="notice notice-' . $severity . ' is-dismissible"><p>';
    //     echo $message;
    //     echo '</p></div>';
    // }

    /**
     * The form fields at Montonio Payments configuration page
     *
     * @return array
     */
    private function getConfigurationFields()
    {
        $this->initConfigurationFields();
        $this->initAdvancedFields();

        return $this->configurationFormFields;

        // return array_merge(
        //     $this->configurationFormFields,
        //     $this->advancedFormFields
        // );
    }

    protected function initConfigurationFields()
    {
        $this->configurationFormFields = array(
            'enabled'                   => array(
                'title'       => __('Enable Montonio Pay Later', 'montonio-for-woocommerce'),
                'label'       => __('Enabled', 'montonio-for-woocommerce'),
                'type'        => 'checkbox',
                'description' => '',
                'default'     => 'no',
            ),
            'montonioSplitEnvironment'  => array(
                'type'        => 'select',
                'title'       => __('Environment', 'montonio-for-woocommerce'),
                'class'       => 'wc-enhanced-select',
                'default'     => 'production',
                'description' => __('Use the Sandbox environment for testing only', 'montonio-for-woocommerce'),
                'options'     => array(
                    'production' => __('Production', 'montonio-for-woocommerce'),
                    'sandbox'    => __('Sandbox', 'montonio-for-woocommerce'),
                ),
            ),
            'montonioSplitAccessKey'    => array(
                'title'   => __('Access Key', 'montonio-for-woocommerce'),
                'type'    => 'text',
                'default' => '', // maybe translatable?
            ),
            'montonioSplitSecretKey'    => array(
                'title'       => __('Secret Key', 'montonio-for-woocommerce'),
                'type'        => 'password',
                'description' => __('Live and Sandbox API keys can be obtained at <a target="_blank" href="https://partner.montonio.com">Montonio Partner System</a>', 'montonio-for-woocommerce'),
                'default'     => '', // maybe translatable?
            ),
            'montonioSplitOrderPrefix'  => array(
                'title'       => __('Order Prefix', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'description' => __('<strong>[MULTISTORE]</strong><br />If you are using Montonio in multiple shops with only one pair of API keys, <br />set the Order Prefix here to distinguish between orders in the Montonio Partner System', 'montonio-for-woocommerce'),
                'default'     => '', // maybe translatable?
            ),
            'titlev2' => array(
                'title'       => __('Title', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'description' => __(
                    'Payment method title that the customer will see on your website.',
                    'montonio-for-woocommerce'
                ),
                'default'     => __('Pay later, no fees', 'montonio-for-woocommerce')
            ),
            'descriptionv2' => array(
                'title'       => __('Description', 'montonio-for-woocommerce'),
                'type'        => 'textarea',
                'css'               => 'width: 400px;',
                'description' => __(
                    'This controls the description which the user sees during checkout.',
                    'montonio-for-woocommerce'
                ),
                'default'     => __('Pay later in up to three payments without any additional fees. 0% interest, 0€ contract fee.', 'montonio-for-woocommerce')
            ),
            'montonioSplitMerchantName' => array(
                'title'       => __('Merchant Name', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'description' => __('<strong>[MULTISTORE]</strong><br />The name to be shown to customers in Montonio application. By default this is your company\'s Display Name (set in the Partner System), but you can also override it here', 'montonio-for-woocommerce'),
                'default'     => '', // maybe translatable?
            ),
            'minOrderTotal' => array(
                'title'       => __('Min order total', 'montonio-for-woocommerce'),
                'type'        => 'text',
                'default'     => 30,
                'description' => __(
                    'Minimum order total to show Montonio Split in checkout. Should not be under 30€.',
                    'montonio-for-woocommerce'
                )
            )
        );
    }

    public function initAdvancedFields()
    {
        $this->advancedFormFields = array(
            'montonioSplitEnqueueMode' => array(
                'title'       => __('Enqueue Mode', 'montonio-for-woocommerce'),
                'type'        => 'select',
                'class'       => 'wc-enhanced-select',
                'default'     => 'enqueue',
                'description' => __('<strong>[ADVANCED]</strong> Select how to enqueue CSS and JavaScript files to your store', 'montonio-for-woocommerce'),
                'options'     => array(
                    'enqueue' => 'Enqueue (recommended)',
                    'echo'    => 'Echo',
                ),
            ),
        );
    }

    /**
     * @return integer
     */
    public function getSettings()
    {
        return $this->settings;
    }

    /**
     * @param integer $settings
     *
     * @return self
     */
    public function setSettings($settings)
    {
        $this->settings = $settings;
        return $this;
    }

    /**
     * @return string
     */
    public function getCurrency()
    {
        return $this->currency;
    }

    /**
     * @param string $currency
     *
     * @return self
     */
    public function setCurrency($currency)
    {
        $this->currency = $currency;
        return $this;
    }

    /**
     * @return string
     */
    public function getLang()
    {
        return $this->lang;
    }

    /**
     * @param string $lang
     *
     * @return self
     */
    public function setLang($lang)
    {
        $this->lang = $lang;

        return $this;
    }

    /**
     * @return array
     */
    public function getFormFields()
    {
        return $this->formFields;
    }

    /**
     * @param array $formFields
     *
     * @return self
     */
    public function setFormFields($formFields)
    {
        $this->formFields = $formFields;

        return $this;
    }

    public function setSplitMethodSettings($setSplitMethodSettings)
    {
        $this->splitMethodSettings = $setSplitMethodSettings;
    }

    public function getSplitMethodSettings()
    {
        return $this->splitMethodSettings;
    }


}
