<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class WC_Montonio_Settings_Migration {

    public function __construct() {
        $this->blik_v1_settings = get_option( 'woocommerce_montonio_blik_payments_settings' );
        $this->blik_v2_settings = get_option( 'woocommerce_wc_montonio_blik_settings' );
        
        $this->pis_v2_settings = get_option( 'woocommerce_wc_montonio_payments_settings' );

        $this->api_settings = get_option( 'woocommerce_wc_montonio_api_settings' );

        $this->migrate();
    }


    /**
     * Run various migrations for database changes after module updates. 
     */
    public function migrate() {

        if ( ! empty( $this->pis_v2_settings['access_key'] ) ) {
            $this->api_settings['access_key'] = $this->pis_v2_settings['access_key'];
        }

        if ( ! empty( $this->pis_v2_settings['secret_key'] ) ) {
            $this->api_settings['secret_key'] = $this->pis_v2_settings['secret_key'];
        }

        if ( ! empty( $this->pis_v2_settings['sandbox_access_key'] ) ) {
            $this->api_settings['sandbox_access_key'] = $this->pis_v2_settings['sandbox_access_key'];
        }

        if ( ! empty( $this->pis_v2_settings['sandbox_secret_key'] ) ) {
            $this->api_settings['sandbox_secret_key'] = $this->pis_v2_settings['sandbox_secret_key'];
        }

        update_option( 'woocommerce_wc_montonio_api_settings', $this->api_settings );


        // Migrate Blik settings
        if ( ! empty( $this->blik_v1_settings['enabled'] ) && $this->blik_v1_settings['enabled'] == 'yes' ) {
            $this->blik_v2_settings['enabled'] = 'yes';

            if ( ! empty( $this->blik_v1_settings['title'] ) ) {
                $this->blik_v2_settings['title'] = $this->blik_v1_settings['title'];
            }

            if ( ! empty( $this->blik_v1_settings['description'] ) ) {
                $this->blik_v2_settings['description'] = $this->blik_v1_settings['description'];
            }

            if ( ! empty( $this->blik_v1_settings['montonioBlikPaymentsEnvironment'] ) && $this->blik_v1_settings['montonioBlikPaymentsEnvironment'] != 'production' ) {
                $this->blik_v2_settings['sandbox_mode'] = 'yes';

                if ( empty( $this->api_settings['sandbox_access_key'] ) ) {
                    $api_keys = $this->get_api_keys();

                    if ( ! empty( $api_keys ) ) {
                        $this->api_settings['sandbox_access_key'] = $api_keys['access_key'];
                        $this->api_settings['sandbox_secret_key'] = $api_keys['secret_key'];
                        update_option( 'woocommerce_wc_montonio_api_settings', $this->api_settings );
                    }
                }
            } else {
                $this->blik_v2_settings['sandbox_mode'] = 'no';

                if ( empty( $this->api_settings['access_key'] ) ) {
                    $api_keys = $this->get_api_keys();

                    if ( ! empty( $api_keys ) ) {
                        $this->api_settings['access_key'] = $api_keys['access_key'];
                        $this->api_settings['secret_key'] = $api_keys['secret_key'];
                        update_option( 'woocommerce_wc_montonio_api_settings', $this->api_settings );
                    }
                }
            }

            update_option( 'woocommerce_wc_montonio_blik_settings', $this->blik_v2_settings );
        }

    }

    public function get_api_keys() {
        $api_keys = array();

        if ( ! empty( $this->blik_v1_settings['montonioBlikPaymentsAccessKey'] ) && ! empty( $this->blik_v1_settings['montonioBlikPaymentsSecretKey'] ) ) {
            $api_keys['access_key'] = $this->blik_v1_settings['montonioBlikPaymentsAccessKey'];
            $api_keys['secret_key'] = $this->blik_v1_settings['montonioBlikPaymentsSecretKey'];    
        }
        
        return $api_keys;
    }
}
new WC_Montonio_Settings_Migration();