<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class WC_Montonio_Display_Admin_Options {

    public static function init() {
		add_action( 'woocommerce_settings_checkout', array( __CLASS__, 'output' ) );
		add_action( 'woocommerce_update_options_checkout', array( __CLASS__, 'save' ) );
	}

	public static function output() {
		global $current_section;
		do_action( 'woocommerce_montonio_settings_checkout_' . $current_section );
	}

    public static function save() {
		global $current_section;
		if ( $current_section && ! did_action( 'woocommerce_update_options_checkout_' . $current_section ) ) {
			do_action( 'woocommerce_update_options_checkout_' . $current_section );
		}
	}

    public static function montonio_admin_menu( $id = null ) {
        $menu_items = array(
            'wc_montonio_api' => 'API Settings',
            'wc_montonio_payments' => 'Bank Payments (2023)',
            'wc_montonio_card' => 'Card Payments (2023)',
            'wc_montonio_blik' => 'Blik',
            'montonio_split' => 'Pay later',
            'montonio' => 'Financing',
            'montonio_shipping' => 'Shipping',
        );
        ?>

        <div class="montonio-menu">
            <ul>
                <?php foreach ( $menu_items as $key => $value ) : ?>
                    <li <?php if ( $id == $key ) { echo 'class="active"'; } ?>>
                        <?php if ( $key == 'montonio_shipping' ) : ?>
                            <a href="<?php echo admin_url( 'admin.php?page=wc-settings&tab=' . $key ); ?>"><?php echo $value; ?></a>
                        <?php else : ?>
                            <a href="<?php echo admin_url( 'admin.php?page=wc-settings&tab=checkout&section=' . $key ); ?>"><?php echo $value; ?></a>
                        <?php endif; ?>
                    </li>
                <?php endforeach; ?>
            </ul>
        </div>
        <?php
    }

    public static function pis_v2_info_banner() {
        ?>
        <div class="montonio-card montonio-card--blue">
            <div class="montonio-card__body">
                <p><?php echo sprintf( __( 'We\'ve released a new version of our Payment Initiation Service. Activate Montonio Bank Payments (2023) to start using it. Read more about the update by <a href="%s" target="_blank">clicking here!</a>', 'montonio-for-woocommerce' ), 'https://help.montonio.com/en/articles/41341-woocommerce-x-pis-v2' ); ?></p>
            </div>
        </div>
        <?php
    }

    public static function card_v2_info_banner() {
        ?>
        <div class="montonio-card montonio-card--blue">
            <div class="montonio-card__body">
                <p><?php echo sprintf( __( 'We\'ve released a new version of our Card Payments service. <a href="%s" target="_blank">Read more about it here</a> before activating it.', 'montonio-for-woocommerce' ), 'https://help.montonio.com/en/articles/58670-woocommerce-x-montonio-card-payments-2023' ); ?></p>
            </div>
        </div>
        <?php
    }

    public static function api_status_banner() {
        $api_settings = get_option( 'woocommerce_wc_montonio_api_settings' );
        ?>

        <div class="montonio-card">
            <div class="montonio-card__body">
                <h4><?php echo __( 'API keys status', 'montonio-for-woocommerce' ); ?></h4>
                <div class="montonio-api-status">    
                    <p><?php echo __( 'Live keys:', 'montonio-for-woocommerce' ); ?></p>
                    <?php if ( ! empty( $api_settings['access_key'] ) && ! empty( $api_settings['secret_key'] ) ) {
                        echo '<span class="api-status--green"><span class="dashicons dashicons-yes-alt"></span>Added</span>';
                    } else {
                        echo '<span class="api-status--gray"><span class="dashicons dashicons-warning"></span>Not Added</span>';
                    } ?>

                    <p><?php echo __( 'Sandbox keys:', 'montonio-for-woocommerce' ); ?></p>
                    <?php if ( ! empty( $api_settings['sandbox_access_key'] ) && ! empty( $api_settings['sandbox_secret_key'] ) ) {
                        echo '<span class="api-status--green"><span class="dashicons dashicons-yes-alt"></span>Added</span>';
                    } else {
                        echo '<span class="api-status--gray"><span class="dashicons dashicons-warning"></span>Not Added</span>';
                    } ?>
                </div>
            </div>

            <div class="montonio-card__footer">
                <a href="<?php echo admin_url( 'admin.php?page=wc-settings&tab=checkout&section=wc_montonio_api' ); ?>" class="components-button is-secondary"><?php echo __('Edit account keys', 'montonio-for-woocommerce' ); ?></a>
            </div>
        </div>
        <?php
    }

    public static function display_options( $title, $settings, $id ) {
        ?>
        <h2><?php echo $title; ?><small class="wc-admin-breadcrumb"><a href="<?php echo admin_url( 'admin.php?page=wc-settings&tab=checkout' ); ?>" aria-label="Return to payments">⤴</a></small></h2>

        <div class="montonio-options-wrapper <?php echo $id; ?>">
            <img class="montonio-logo" src="https://montonio.de/wp-content/themes/montonio/assets/images/logo.svg">

            <?php self::montonio_admin_menu( $id ); ?>

            <?php if ( $id == 'wc_montonio_payments' ) {
                self::pis_v2_info_banner(); 
            } ?>

            <?php if ( $id == 'wc_montonio_card' ) {
                self::card_v2_info_banner(); 
            } ?>
            
            <?php if ( $id != 'wc_montonio_api' ) {
                self::api_status_banner(); 
            } ?>

            <div class="montonio-card">
                <div class="montonio-card__body">
                    <table class="form-table">
                        <?php echo $settings; ?>
                    </table>
                </div>
            </div>
        </div>
    

        <?php
    }
}
WC_Montonio_Display_Admin_Options::init();
