<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class WC_Montonio_Helper {

    /**
     * Method that returns the appropriate locale identifier used in Montonio's systems
     *
     * @param string $locale The locale to search for
     * @return string identifier for locale if found, en_US by default
     */
    public static function get_locale( $locale ) {
        if ( in_array( $locale, array( 'lt', 'lt_LT', 'lt_lt', 'lt-LT', 'lt-lt' ) ) ) {
            return 'lt';
        } else if ( in_array( $locale, array( 'lv', 'lv_LV', 'lv_lv', 'lv-LV', 'lv-lv' ) ) ) {
            return 'lv';
        } else if ( in_array( $locale, array( 'ru', 'ru_RU', 'ru_ru', 'ru-RU', 'ru-ru' ) ) ) {
            return 'ru';
        } else if ( in_array( $locale, array( 'et', 'ee', 'EE', 'ee_EE', 'ee-EE', 'et_EE', 'et-EE', 'et_ee', 'et-ee' ) ) ) {
            return 'et';
        } else if ( in_array( $locale, array( 'fi', 'fi_FI', 'fi_fi', 'fi-FI', 'fi-fi' ) ) ) {
            return 'fi';
        } else if ( in_array( $locale, array( 'pl', 'pl_PL', 'pl_pl', 'pl-PL', 'pl-pl' ) ) ) {
            return 'pl';
        } else if ( in_array( $locale, array( 'de', 'de_DE', 'de_de', 'de-DE', 'de-de' ) ) ) {
            return 'de';
        } else {
            return 'en';
        }
    }

    /**
     * Method that returns the appropriate currency identifier used in Montonio's systems
     *
     * @param string $locale The currency to search for
     * @return string identifier for currency if found, EUR by default
     */
    public static function get_currency() {
        global $woocommerce_wpml;

        $currency = get_woocommerce_currency();

        // WPML Multi-Currency support
        if ( ! is_null( $woocommerce_wpml ) ) {
            if ( function_exists( 'wcml_is_multi_currency_on' ) && wcml_is_multi_currency_on() ) {
                $currency = $woocommerce_wpml->multi_currency->get_client_currency();
            }
        }

        if ( $currency === 'PLN' ) {
            return 'PLN';
        } else {
            return 'EUR';
        }
    }

    public static function is_client_currency_supported( $supported_currencies = array( 'EUR', 'PLN' ) ) {
        global $woocommerce_wpml;

        $currency = get_woocommerce_currency();

        // WPML Multi-Currency support
        if ( ! is_null($woocommerce_wpml ) ) {
            if ( function_exists( 'wcml_is_multi_currency_on' ) && wcml_is_multi_currency_on() ) {
                $currency = $woocommerce_wpml->multi_currency->get_client_currency();
            }
        }

        return in_array( $currency, $supported_currencies );
    }

    public static function get_payment_description( $custom_description, $order_id, $descripton ) {
        $order = wc_get_order( $order_id );
        $order_number = apply_filters( 'wc_montonio_merchant_reference_display', $order->get_order_number() );

        if ( $custom_description == 'yes' && ! empty( $descripton ) ) {
            $find    = '{order_number}';
            $replace = $order_number;

            $description = str_replace( $find, $replace, $descripton );

            return sanitize_text_field( $description );
        }

        return $order_number;
    }
}